Partners and Support
=====================


Development of CLEASE was supported by `LiRichFCC <https://www.lirichfcc.eu>`_ (H2020, #766581)
and `BIG-MAP <https://www.big-map.eu/>`_ (H2020, #957189).

.. image:: ./resources/lirich_fcc.png
    :target: https://www.lirichfcc.eu
    :align: center
    :width: 200


.. image:: ./resources/bigmap.png
    :target: https://www.big-map.eu/
    :width: 200
    :align: center
